Partition uncertainty in climate responses using an ANOVA inferred with a Bayesian approach.
QUALYPSO.ANOVA(phiStar, scenAvail, listOption = NULL, namesEff)list with the following fields:
GRANDMEAN: List of estimates for the grand mean:
strong: MEAN: vector of length n of posterior means
strong: SD: vector of length n of posterior standard dev.
strong: CI: matrix n x 2 of credible intervals of
probability probCI given in listOption.
strong: QUANT: matrix n x nQ of quantiles related
to the probabilities quantilePosterior given in listOption
RESIDUALVAR: List of estimates for the variance of the residual errors:
strong: MEAN: vector of length n of posterior means
strong: SD: vector of length n of posterior standard dev.
strong: CI: matrix n x 2 of credible intervals of
probability probCI given in listOption.
strong: QUANT: matrix n x nQ of quantiles related
to the probabilities quantilePosterior given in listOption
MAINEFFECT: List of estimates for the main effects. For each main effect (GCM, RCM,..), each element of the list contains a list with:
strong: MEAN: matrix n x nTypeEff of posterior means
strong: SD: matrix n x nTypeEff of posterior standard dev.
strong: CI: array n x 2 x nTypeEff of credible
intervals of probability probCI given in listOption.
strong: QUANT: array n x nQ x nTypeEff of
quantiles related to the probabilities quantilePosterior given in
listOption
CHANGEBYEFFECT: For each main effect, list of estimates for the mean change by main effect, i.e. mean change by scenario (RCP4.5). For each main effect (GCM, RCM,..), each element of the list contains a list with:
strong: MEAN: matrix n x nTypeEff of posterior means
strong: SD: matrix n x nTypeEff of posterior standard dev.
strong: CI: array n x 2 x nTypeEff of credible
intervals of probability probCI given in listOption.
strong: QUANT: array n x nQ x nTypeEff of
quantiles related to the probabilities quantilePosterior given in
listOption
EFFECTVAR: variability related to the main effects (i.e.
variability between the different RCMs, GCMs,..). Matrix n x
nTypeEff
CONTRIB_EACH_EFFECT: Contribution of each individual effect
to its component (percentage), e.g. what is the contribution of GCM1 to the
variability related to GCMs. For each main effect (GCM, RCM,..), each
element of the list contains a matrix n x nTypeEff
listOption: list of options used to obtained these results
(obtained from QUALYPSO.check.option)
listScenarioInput: list of scenario characteristics
(obtained from QUALYPSO.process.scenario)
matrix of climate change responses (absolute or relative changes): nS x n.
n can be the number of time steps or the number of grid points
data.frame nS x nEff with the nEff characteristics (e.g. type of GCM) for each of the nS x nS scenarios
list of options (see QUALYPSO)
names of the main effects
Guillaume Evin
Evin, G., B. Hingray, J. Blanchet, N. Eckert, S. Morin, and D. Verfaillie (2020) Partitioning Uncertainty Components of an Incomplete Ensemble of Climate Projections Using Data Augmentation. Journal of Climate. <doi:10.1175/JCLI-D-18-0606.1>.