Fit trends for each simulation chain of an ensemble of nS projections. Each simulation chain is a time series
of nY time steps (e.g. number of years).
fit.climate.response(Y, args.smooth.spline, Xmat, Xfut, typeChangeVariable)list with the following fields for each simulation chain:
YStar: nS x nY, change variable
phiStar: nS x nF, climate change responses
etaStar: nS x nY, deviation from the climate change response
due to the internal variability, for Xmat
phi: nS x nF, raw trends obtained using smooth.spline
climateResponse: output from smooth.spline
varInterVariability: scalar, internal variability component of the MME
matrix of simulation chains: nS x nY
list of arguments to be passed to smooth.spline.
The names attribute of args.smooth.spline gives the argument
names (see do.call).
matrix of predictors corresponding to the projections, e.g. time or global temperature.
values of the predictor over which the ANOVA will be applied.
type of change variable: "abs" (absolute, value by default) or "rel" (relative)
Guillaume Evin
See QUALYPSO for further information on arguments indexReferenceYear and typeChangeVariable.
Evin, G., B. Hingray, J. Blanchet, N. Eckert, S. Morin, and D. Verfaillie (2020) Partitioning Uncertainty Components of an Incomplete Ensemble of Climate Projections Using Data Augmentation. Journal of Climate. J. Climate, 32, 2423–2440. <doi:10.1175/JCLI-D-18-0606.1>.